@@ -142,7 +142,7 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
         desc='this option lets you input a rectangular array of 1 or more '
         'baseline vectors from a file. This method is a fast way to '
         'include a lot of baseline regressors in one step. ',
-        argstr='ortvec %s')
+        argstr='-ortvec %s %s')
     x1D = File(desc='specify name for saved X matrix', argstr='-x1D %s')
     x1D_stop = traits.Bool(
         desc='stop running after writing .xmat.1D file', argstr='-x1D_stop')
@@ -153,9 +153,10 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
         'instead of the bucket dataset, if possible.',
         argstr='-cbucket %s')
     out_file = File(desc='output statistics file', argstr='-bucket %s')
-    jobs = traits.Int(
+    num_threads = traits.Int(
         desc='run the program with provided number of sub-processes',
-        argstr='-jobs %d')
+        argstr='-jobs %d',
+        nohash=True)
     fout = traits.Bool(
         desc='output F-statistic for each stimulus', argstr='-fout')
     rout = traits.Bool(
@@ -165,6 +166,10 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
     vout = traits.Bool(
         desc='output the sample variance (MSE) for each stimulus',
         argstr='-vout')
+    nofdr = traits.Bool(
+        desc="Don't compute the statistic-vs-FDR curves for the bucket "
+             "dataset.",
+        argstr='-noFDR')
     global_times = traits.Bool(
         desc='use global timing for stimulus timing files',
         argstr='-global_times',
@@ -293,11 +298,14 @@ class Deconvolve(AFNICommand):
             outputs['x1D'] = self._gen_fname(
                 suffix='.xmat.1D', **_gen_fname_opts)
 
+        if isdefined(self.inputs.cbucket):
+            outputs['cbucket'] = os.path.abspath(self.inputs.cbucket)
+
         outputs['reml_script'] = self._gen_fname(
             suffix='.REML_cmd', **_gen_fname_opts)
         # remove out_file from outputs if x1d_stop set to True
         if self.inputs.x1D_stop:
-            del outputs['out_file']
+            del outputs['out_file'], outputs['cbucket']
         else:
             outputs['out_file'] = os.path.abspath(self.inputs.out_file)
 
@@ -652,3 +660,12 @@ class Synthesize(AFNICommand):
     _cmd = '3dSynthesize'
     input_spec = SynthesizeInputSpec
     output_spec = AFNICommandOutputSpec
+
+    def _list_outputs(self):
+        outputs = self.output_spec().get()
+
+        for key in outputs.keys():
+            if isdefined(self.inputs.get()[key]):
+                outputs[key] = os.path.abspath(self.inputs.get()[key])
+
+        return outputs
