@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 import os.path as op
 
@@ -10,9 +11,8 @@ import networkx as nx
 
 from ... import logging
 from ...utils.misc import package_check
-from ..base import (BaseInterface, BaseInterfaceInputSpec, traits,
-                    File, TraitedSpec, InputMultiPath,
-                    OutputMultiPath, isdefined)
+from ..base import (BaseInterface, BaseInterfaceInputSpec, traits, File,
+                    TraitedSpec, InputMultiPath, OutputMultiPath, isdefined)
 iflogger = logging.getLogger('interface')
 
 have_cv = True
@@ -32,28 +32,64 @@ def ntwks_to_matrices(in_files, edge_key):
     for idx, name in enumerate(in_files):
         graph = nx.read_gpickle(name)
         for u, v, d in graph.edges(data=True):
-            graph[u][v]['weight'] = d[edge_key]  # Setting the edge requested edge value as weight value
+            try:
+                graph[u][v]['weight'] = d[
+                    edge_key]  # Setting the edge requested edge value as weight value
+            except:
+                raise KeyError(
+                    "the graph edges do not have {} attribute".format(
+                        edge_key))
         matrix[:, :, idx] = nx.to_numpy_matrix(graph)  # Retrieve the matrix
     return matrix
 
 
 class NetworkBasedStatisticInputSpec(BaseInterfaceInputSpec):
-    in_group1 = InputMultiPath(File(exists=True), mandatory=True, desc='Networks for the first group of subjects')
-    in_group2 = InputMultiPath(File(exists=True), mandatory=True, desc='Networks for the second group of subjects')
-    node_position_network = File(desc='An optional network used to position the nodes for the output networks')
-    number_of_permutations = traits.Int(1000, usedefault=True, desc='Number of permutations to perform')
+    in_group1 = InputMultiPath(
+        File(exists=True),
+        mandatory=True,
+        desc='Networks for the first group of subjects')
+    in_group2 = InputMultiPath(
+        File(exists=True),
+        mandatory=True,
+        desc='Networks for the second group of subjects')
+    node_position_network = File(
+        desc=
+        'An optional network used to position the nodes for the output networks'
+    )
+    number_of_permutations = traits.Int(
+        1000, usedefault=True, desc='Number of permutations to perform')
     threshold = traits.Float(3, usedefault=True, desc='T-statistic threshold')
-    t_tail = traits.Enum('left', 'right', 'both', usedefault=True, desc='Can be one of "left", "right", or "both"')
-    edge_key = traits.Str('number_of_fibers', usedefault=True, desc='Usually "number_of_fibers, "fiber_length_mean", "fiber_length_std" for matrices made with CMTK'
-                          'Sometimes "weight" or "value" for functional networks.')
-    out_nbs_network = File(desc='Output network with edges identified by the NBS')
-    out_nbs_pval_network = File(desc='Output network with p-values to weight the edges identified by the NBS')
+    t_tail = traits.Enum(
+        'left',
+        'right',
+        'both',
+        usedefault=True,
+        desc='Can be one of "left", "right", or "both"')
+    edge_key = traits.Str(
+        'number_of_fibers',
+        usedefault=True,
+        desc=
+        'Usually "number_of_fibers, "fiber_length_mean", "fiber_length_std" for matrices made with CMTK'
+        'Sometimes "weight" or "value" for functional networks.')
+    out_nbs_network = File(
+        desc='Output network with edges identified by the NBS')
+    out_nbs_pval_network = File(
+        desc=
+        'Output network with p-values to weight the edges identified by the NBS'
+    )
 
 
 class NetworkBasedStatisticOutputSpec(TraitedSpec):
-    nbs_network = File(exists=True, desc='Output network with edges identified by the NBS')
-    nbs_pval_network = File(exists=True, desc='Output network with p-values to weight the edges identified by the NBS')
-    network_files = OutputMultiPath(File(exists=True), desc='Output network with edges identified by the NBS')
+    nbs_network = File(
+        exists=True, desc='Output network with edges identified by the NBS')
+    nbs_pval_network = File(
+        exists=True,
+        desc=
+        'Output network with p-values to weight the edges identified by the NBS'
+    )
+    network_files = OutputMultiPath(
+        File(exists=True),
+        desc='Output network with edges identified by the NBS')
 
 
 class NetworkBasedStatistic(BaseInterface):
@@ -77,11 +113,16 @@ class NetworkBasedStatistic(BaseInterface):
     output_spec = NetworkBasedStatisticOutputSpec
 
     def _run_interface(self, runtime):
+
+        if not have_cv:
+            raise ImportError("cviewer library is not available")
+
         THRESH = self.inputs.threshold
         K = self.inputs.number_of_permutations
         TAIL = self.inputs.t_tail
         edge_key = self.inputs.edge_key
-        details = edge_key + '-thresh-' + str(THRESH) + '-k-' + str(K) + '-tail-' + TAIL + '.pck'
+        details = edge_key + '-thresh-' + str(THRESH) + '-k-' + str(
+            K) + '-tail-' + TAIL + '.pck'
 
         # Fill in the data from the networks
         X = ntwks_to_matrices(self.inputs.in_group1, edge_key)
@@ -111,21 +152,22 @@ class NetworkBasedStatistic(BaseInterface):
             node_ntwk_name = self.inputs.in_group1[0]
 
         node_network = nx.read_gpickle(node_ntwk_name)
-        iflogger.info('Populating node dictionaries with attributes from {node}'.format(node=node_ntwk_name))
+        iflogger.info('Populating node dictionaries with attributes from %s',
+                      node_ntwk_name)
 
-        for nid, ndata in node_network.nodes_iter(data=True):
-            nbsgraph.node[nid] = ndata
-            nbs_pval_graph.node[nid] = ndata
+        for nid, ndata in node_network.nodes(data=True):
+            nbsgraph.nodes[nid] = ndata
+            nbs_pval_graph.nodes[nid] = ndata
 
         path = op.abspath('NBS_Result_' + details)
         iflogger.info(path)
         nx.write_gpickle(nbsgraph, path)
-        iflogger.info('Saving output NBS edge network as {out}'.format(out=path))
+        iflogger.info('Saving output NBS edge network as %s', path)
 
         pval_path = op.abspath('NBS_P_vals_' + details)
         iflogger.info(pval_path)
         nx.write_gpickle(nbs_pval_graph, pval_path)
-        iflogger.info('Saving output p-value network as {out}'.format(out=pval_path))
+        iflogger.info('Saving output p-value network as %s', pval_path)
         return runtime
 
     def _list_outputs(self):
@@ -135,7 +177,8 @@ class NetworkBasedStatistic(BaseInterface):
         K = self.inputs.number_of_permutations
         TAIL = self.inputs.t_tail
         edge_key = self.inputs.edge_key
-        details = edge_key + '-thresh-' + str(THRESH) + '-k-' + str(K) + '-tail-' + TAIL + '.pck'
+        details = edge_key + '-thresh-' + str(THRESH) + '-k-' + str(
+            K) + '-tail-' + TAIL + '.pck'
         path = op.abspath('NBS_Result_' + details)
         pval_path = op.abspath('NBS_P_vals_' + details)
 
